@@ -1,5 +1,5 @@
 from datetime import datetime, timedelta
-from typing import TYPE_CHECKING, Any, Dict, Optional, TypeVar
+from typing import TYPE_CHECKING, Any, Dict, Generic, Optional, Type, TypeVar
 from uuid import uuid4
 
 from django.conf import settings
@@ -22,6 +22,8 @@ from .utils import (
 if TYPE_CHECKING:
     from .backends import TokenBackend
 
+T = TypeVar("T", bound="Token")
+
 AuthUser = TypeVar("AuthUser", AbstractBaseUser, TokenUser)
 
 
@@ -195,7 +197,7 @@ class Token:
             raise TokenError(format_lazy(_("Token '{}' claim has expired"), claim))
 
     @classmethod
-    def for_user(cls, user: AuthUser) -> "Token":
+    def for_user(cls: Type[T], user: AuthUser) -> T:
         """
         Returns an authorization token for the given user that will be provided
         after authenticating the user's credentials.
@@ -229,7 +231,7 @@ class Token:
         return self.token_backend
 
 
-class BlacklistMixin:
+class BlacklistMixin(Generic[T]):
     """
     If the `rest_framework_simplejwt.token_blacklist` app was configured to be
     used, tokens created from `BlacklistMixin` subclasses will insert
@@ -263,11 +265,14 @@ class BlacklistMixin:
             """
             jti = self.payload[api_settings.JTI_CLAIM]
             exp = self.payload["exp"]
+            user_id = self.payload.get(api_settings.USER_ID_CLAIM)
 
             # Ensure outstanding token exists with given jti
             token, _ = OutstandingToken.objects.get_or_create(
                 jti=jti,
                 defaults={
+                    "user_id": user_id,
+                    "created_at": self.current_time,
                     "token": str(self),
                     "expires_at": datetime_from_epoch(exp),
                 },
@@ -276,7 +281,7 @@ class BlacklistMixin:
             return BlacklistedToken.objects.get_or_create(token=token)
 
         @classmethod
-        def for_user(cls, user: AuthUser) -> Token:
+        def for_user(cls: Type[T], user: AuthUser) -> T:
             """
             Adds this token to the outstanding token list.
             """
@@ -296,7 +301,7 @@ class BlacklistMixin:
             return token
 
 
-class SlidingToken(BlacklistMixin, Token):
+class SlidingToken(BlacklistMixin["SlidingToken"], Token):
     token_type = "sliding"
     lifetime = api_settings.SLIDING_TOKEN_LIFETIME
 
@@ -317,7 +322,7 @@ class AccessToken(Token):
     lifetime = api_settings.ACCESS_TOKEN_LIFETIME
 
 
-class RefreshToken(BlacklistMixin, Token):
+class RefreshToken(BlacklistMixin["RefreshToken"], Token):
     token_type = "refresh"
     lifetime = api_settings.REFRESH_TOKEN_LIFETIME
     no_copy_claims = (
